Middleware
==========

ASGI middleware components.

.. automodule:: genro_asgi.middleware
   :members:
   :undoc-members:
   :show-inheritance:

Authentication
--------------

.. automodule:: genro_asgi.middleware.authentication
   :members:
   :undoc-members:
   :show-inheritance:

Cache
-----

.. automodule:: genro_asgi.middleware.cache
   :members:
   :undoc-members:
   :show-inheritance:

CORS Middleware
---------------

.. automodule:: genro_asgi.middleware.cors
   :members:
   :undoc-members:
   :show-inheritance:

Error Handling
--------------

.. automodule:: genro_asgi.middleware.errors
   :members:
   :undoc-members:
   :show-inheritance:

Compression
-----------

.. automodule:: genro_asgi.middleware.compression
   :members:
   :undoc-members:
   :show-inheritance:

Logging
-------

.. automodule:: genro_asgi.middleware.logging
   :members:
   :undoc-members:
   :show-inheritance:
